// -*-c++-*-
//===========================================================
//=     University of Illinois at Urbana/Champaign          =
//=     Department of Computer Science                      =
//=     Dr. Dan Roth - Cognitive Computation Group          =
//=                                                         =
//=  Project: Snow                                          =
//=                                                         =
//=   Module: GlobalParams.h                                =
//=  Version: 2.1                                           =
//=  Authors: Jeff Rosen and Andrew Carlson                 =
//=     Date: xx/xx/99                                      = 
//=                                                         =
//= Comments:                                               =
//===========================================================

#ifndef __GLOBALPARAMS_H__
#define __GLOBALPARAMS_H__

#include "TargetIdSet.h"
#include <string>
#include <vector>
#include <map>

using namespace std;

struct GlobalParams
{
    GlobalParams();
    
    RunMode         runMode;
    Counter         currentCycle;
    Counter         cycles;
    DiscardMethod   discardMethod;
    PredictMethod   predictMethod; 
    double          discardThreshold;
    Counter         firstDiscardCycle;
    Counter         minCyclesAfterDiscard;
    Counter         eligibilityThreshold;
    Counter         curveInterval;
    vector<Counter> curveCycles;
    TargetIdSet     targetIds;
    string          inputFile;
    string          outputFile; // for test mode only
    string          testFile; // for train/test mode only
    string          networkFile;
    string          errorFile;
    string          algorithmSpecification;
    string          evalExample;
    bool            sparseNetwork;
    bool            noFirstCycleUpdate;
    bool            onlineLearning;
    Verbosity       verbosity;
    double          smoothing;
    double          bayesSmoothing;
    double          predictionThreshold;
    bool            labelsPresent;
    bool            multipleLabels;  
};

inline GlobalParams::GlobalParams() :
        runMode(MODE_TRAIN),
        currentCycle(0),
        cycles(2),
        discardMethod(DISCARD_NONE),
        predictMethod(ACCURACY),
        discardThreshold(0.2),
        firstDiscardCycle(2),
        minCyclesAfterDiscard(1),
        eligibilityThreshold(2),
        curveInterval(0),
        sparseNetwork(true),
        noFirstCycleUpdate(false),
        onlineLearning(false),
        verbosity(VERBOSE_MIN),
        smoothing(0.0),
        bayesSmoothing(15.0),
        predictionThreshold(-1.0),
        labelsPresent(true),
        multipleLabels(false)
{
}

extern GlobalParams globalParams;

typedef map<FeatureID, int> FeatureCountMap;
extern FeatureCountMap globalFeatureCount;

#endif

